Crate hyperlight_guest_bin

Crate hyperlight_guest_bin 

Re-exports

pub use crate::guest_function::definition::GuestFunc;
pub use hyperlight_libc as libc;

Modules

error
exception
guest_function
guest_logger
host_comm
memory
paging

Statics

GUEST_HANDLE
OS_PAGE_SIZE
The size of one page in the host OS, which may have some impacts on how buffers for host consumption should be aligned. Code only working with the guest page tables should use [hyperlight_common::vm::PAGE_SIZE] instead.

Attribute Macros

dispatch
Attribute macro to mark a function as the dispatch function for the guest. This is the function that will be called by the host when a function call is made to a function that is not registered with the host.
guest_function
Attribute macro to mark a function as a guest function. This will register the function so that it can be called by the host.
host_function
Attribute macro to mark a function as a host function. This will generate a function that calls the host function with the same name.
main
Attribute macro to mark a function as the main entry point for the guest. This will generate a function that is called by the host at program initialization.