#[main]
Attribute macro to mark a function as the main entry point for the guest. This will generate a function that is called by the host at program initialization.
use hyperlight_guest_bin::main; #[main] fn main() { // do some initialization work here, e.g., initialize global state, etc. }