Macros
- bail
- Macro to return early with a
Err(HyperlightGuestError). Usage: - ensure
- Macro to ensure a condition is true, otherwise returns early with a
Err(HyperlightGuestError). Usage:
Structs
Enums
- Error
Code ErrorCoderepresents an error that occurred in the Hyperlight Guest.
Traits
- Guest
Error Context - Extension trait to add context to
Option<T>andResult<T, E>types in guest code, converting them toResult<T, HyperlightGuestError>.