pub struct GuestFunctionDefinition<F: Copy> {
pub function_name: String,
pub parameter_types: Vec<ParameterType>,
pub return_type: ReturnType,
pub function_pointer: F,
}Expand description
The definition of a function exposed from the guest to the host.
The type parameter F is the function pointer type. For Rust guests this
is GuestFunc; the C API uses its own CGuestFunc type.
Fields
function_name: StringThe function name
parameter_types: Vec<ParameterType>The type of the parameter values for the host function call.
return_type: ReturnTypeThe type of the return value from the host function call
function_pointer: FThe function pointer to the guest function.
Implementations
Sourceimpl<F: Copy> GuestFunctionDefinition<F>
impl<F: Copy> GuestFunctionDefinition<F>
Sourcepub fn new(
function_name: String,
parameter_types: Vec<ParameterType>,
return_type: ReturnType,
function_pointer: F,
) -> Self
pub fn new( function_name: String, parameter_types: Vec<ParameterType>, return_type: ReturnType, function_pointer: F, ) -> Self
Create a new GuestFunctionDefinition.
Sourcepub fn from_fn<Output, Args>(
function_name: String,
function: impl AsGuestFunctionDefinition<Output, Args>,
) -> GuestFunctionDefinition<GuestFunc>where
Args: ParameterTuple,
Output: SupportedReturnType,
pub fn from_fn<Output, Args>(
function_name: String,
function: impl AsGuestFunctionDefinition<Output, Args>,
) -> GuestFunctionDefinition<GuestFunc>where
Args: ParameterTuple,
Output: SupportedReturnType,
Create a new GuestFunctionDefinition<GuestFunc> from a function that
implements AsGuestFunctionDefinition.
Sourcepub fn verify_parameters(&self, parameter_types: &[ParameterType]) -> Result<()>
pub fn verify_parameters(&self, parameter_types: &[ParameterType]) -> Result<()>
Verify that self has same signature as the provided parameter_types.