#[unsafe(no_mangle)]pub unsafe extern "C" fn malloc(size: usize) -> *mut c_voidExpand description
Allocates a block of memory with the given size. The memory is not guaranteed to be initialized to 0s.
Safety
The returned pointer must be freed with memory::free when it is no longer needed, otherwise memory will leak.