Module error

Module error 

Macros

bail
Macro to return early with a Err(HyperlightGuestError). Usage:
ensure
Macro to ensure a condition is true, otherwise returns early with a Err(HyperlightGuestError). Usage:

Structs

HyperlightGuestError

Enums

ErrorCode
ErrorCode represents an error that occurred in the Hyperlight Guest.

Traits

GuestErrorContext
Extension trait to add context to Option<T> and Result<T, E> types in guest code, converting them to Result<T, HyperlightGuestError>.

Type Aliases

Result