pub struct GuestFunctionRegister<F: Copy> { /* private fields */ }Expand description
Represents the functions that the guest exposes to the host.
Implementations
Sourceimpl<F: Copy> GuestFunctionRegister<F>
impl<F: Copy> GuestFunctionRegister<F>
Sourcepub fn register(
&mut self,
guest_function: GuestFunctionDefinition<F>,
) -> Option<GuestFunctionDefinition<F>>
pub fn register( &mut self, guest_function: GuestFunctionDefinition<F>, ) -> Option<GuestFunctionDefinition<F>>
Register a new GuestFunctionDefinition into self.
If a function with the same name already exists, it will be replaced.
None is returned if the function name was not previously registered,
otherwise the previous GuestFunctionDefinition is returned.
Sourcepub fn get(&self, function_name: &str) -> Option<&GuestFunctionDefinition<F>>
pub fn get(&self, function_name: &str) -> Option<&GuestFunctionDefinition<F>>
Gets a GuestFunctionDefinition by its name field.
Sourceimpl GuestFunctionRegister<GuestFunc>
impl GuestFunctionRegister<GuestFunc>
pub fn register_fn<Output, Args>(
&mut self,
name: impl Into<String>,
f: impl AsGuestFunctionDefinition<Output, Args>,
)where
Args: ParameterTuple,
Output: SupportedReturnType,